var annotated_dup =
[
    [ "jsAccountInfo", "structjs_account_info.html", "structjs_account_info" ],
    [ "jsAccountLimits", "structjs_account_limits.html", "structjs_account_limits" ],
    [ "jsAPIStats", "structjs_a_p_i_stats.html", "structjs_a_p_i_stats" ],
    [ "jsClusterInfo", "structjs_cluster_info.html", "structjs_cluster_info" ],
    [ "jsConsumerConfig", "structjs_consumer_config.html", "structjs_consumer_config" ],
    [ "jsConsumerInfo", "structjs_consumer_info.html", "structjs_consumer_info" ],
    [ "jsConsumerInfoList", "structjs_consumer_info_list.html", "structjs_consumer_info_list" ],
    [ "jsConsumerNamesList", "structjs_consumer_names_list.html", "structjs_consumer_names_list" ],
    [ "jsConsumerSequenceMismatch", "structjs_consumer_sequence_mismatch.html", "structjs_consumer_sequence_mismatch" ],
    [ "jsDirectGetMsgOptions", "structjs_direct_get_msg_options.html", "structjs_direct_get_msg_options" ],
    [ "jsExternalStream", "structjs_external_stream.html", "structjs_external_stream" ],
    [ "jsFetchRequest", "structjs_fetch_request.html", "structjs_fetch_request" ],
    [ "jsLostStreamData", "structjs_lost_stream_data.html", "structjs_lost_stream_data" ],
    [ "jsMsgMetaData", "structjs_msg_meta_data.html", "structjs_msg_meta_data" ],
    [ "jsOptions", "structjs_options.html", "structjs_options" ],
    [ "jsPeerInfo", "structjs_peer_info.html", "structjs_peer_info" ],
    [ "jsPlacement", "structjs_placement.html", "structjs_placement" ],
    [ "jsPubAck", "structjs_pub_ack.html", "structjs_pub_ack" ],
    [ "jsPubAckErr", "structjs_pub_ack_err.html", "structjs_pub_ack_err" ],
    [ "jsPubOptions", "structjs_pub_options.html", "structjs_pub_options" ],
    [ "jsRePublish", "structjs_re_publish.html", "structjs_re_publish" ],
    [ "jsSequenceInfo", "structjs_sequence_info.html", "structjs_sequence_info" ],
    [ "jsSequencePair", "structjs_sequence_pair.html", "structjs_sequence_pair" ],
    [ "jsStreamConfig", "structjs_stream_config.html", "structjs_stream_config" ],
    [ "jsStreamInfo", "structjs_stream_info.html", "structjs_stream_info" ],
    [ "jsStreamInfoList", "structjs_stream_info_list.html", "structjs_stream_info_list" ],
    [ "jsStreamNamesList", "structjs_stream_names_list.html", "structjs_stream_names_list" ],
    [ "jsStreamSource", "structjs_stream_source.html", "structjs_stream_source" ],
    [ "jsStreamSourceInfo", "structjs_stream_source_info.html", "structjs_stream_source_info" ],
    [ "jsStreamState", "structjs_stream_state.html", "structjs_stream_state" ],
    [ "jsStreamStateSubject", "structjs_stream_state_subject.html", "structjs_stream_state_subject" ],
    [ "jsStreamStateSubjects", "structjs_stream_state_subjects.html", "structjs_stream_state_subjects" ],
    [ "jsSubOptions", "structjs_sub_options.html", "structjs_sub_options" ],
    [ "jsTier", "structjs_tier.html", "structjs_tier" ],
    [ "kvConfig", "structkv_config.html", "structkv_config" ],
    [ "kvEntryList", "structkv_entry_list.html", "structkv_entry_list" ],
    [ "kvKeysList", "structkv_keys_list.html", "structkv_keys_list" ],
    [ "kvPurgeOptions", "structkv_purge_options.html", "structkv_purge_options" ],
    [ "kvWatchOptions", "structkv_watch_options.html", "structkv_watch_options" ],
    [ "natsMsgList", "structnats_msg_list.html", "structnats_msg_list" ]
];